Modular representations of using calculus
Abstract.
We show that certain modular induced representations of can be written as cokernels of operators acting on symmetric power representations of . When the induction is from the Borel subgroup, respectively the anisotropic torus, the operators involve multiplication by newly defined twisted Dickson polynomials, respectively, twisted Serre operators. Our isomorphisms are explicitly defined using differential operators. As a corollary, we improve some periodicity results for quotients in the theta filtration.
Key words and phrases:
modular representations, induced representations, differential operators1991 Mathematics Subject Classification
20C33, 20C201. Introduction
Let be the general linear group and let be a prime. Let for be the -th symmetric power representation of the standard two-dimensional representation of . It is modeled on homogeneous polynomials of degree over in two variables and with the usual action of . Let be the theta or Dickson polynomial on which acts by determinant. Let for be the sub-representation of consisting of polynomials divisible by copies of . The sequence is called the theta filtration of .
1.1. Principal series
It is a classical fact going back to Glover [Glo78, (4.2)] that is periodic in with period where . This is proved nowadays by noting that
| (1.1) |
is a principal series representation of obtained by inducing the character of the Borel subgroup to [Roz14, Lemma 2.4], and by noting that the character depends only on modulo . Similar periodicity results have been investigated for higher quotients in the theta filtration of . Indeed, it was shown in [GV22, Lemma 4.1] that for , the quotient is periodic in modulo by constructing an embedding
| (1.2) |
where is the ring of generalized dual numbers (with ), noting that only depends on modulo , and by showing that the image of (1.2) is independent of modulo .
The map (1.2) is no longer surjective when . In this paper, instead of working with generalized dual numbers and characters of the inducing subgroup, we work with the induction of higher dimensional representations of the inducing subgroup and obtain isomorphisms between and induced spaces. We have:
Theorem 1.1.
Let and . Then, we have the following explicit isomorphisms:
- (1)
If , then
(1.3) where is the representation of obtained by restriction from .
- (2)
If and , then
where is the split representation of obtained as the semi-simplification of .
The map in (1.3) generalizes the ‘evaluation of the polynomial at the second row of a matrix’ map that is used to prove (1.1) and (1.2). Additionally, it involves the use of a differential operator . Such operators have found sporadic use in the literature (see [Glo78] and [BG15]), but are used systematically throughout this paper. We also need to divide by constants which do not vanish if (cf. (2.5)).
Consider now the case with , that is, is in one of the congruence classes modulo . While it is well known that the individual principal series occurring as subquotients in the theta filtration are extensions of two Jordan-Hölder factors (which split exactly when mod ), it is not as clear whether the extensions between consecutive principal series
| (1.4) |
for occurring in the theta filtration split. We show that if , then there is exactly one such that (1.4) splits. Indeed, since with mod we are reduced to analyzing the case . If , then does not split by (1.3) and by (the converse of) the exactness of induction [Alp86, §8, Lemma 6 (5)]. Modifying the above mentioned differential operator by dropping the constant mentioned above (cf. (2.8)), in the second part of the theorem we show that if , then
splits. In other words, if , then the two-dimensional standard representation in (1.3) gets replaced by the split representation of . We deduce that the extensions (1.4) split exactly when mod ; moreover, under this condition, we have:
| (1.5) |
As a corollary of Theorem 1.1, we obtain a strengthening of the afore-mentioned periodicity result from [GV22] in the case that since again the right hand side of (1.3) only depends on modulo and not on modulo . Thus, to obtain periodicity in this case, we no longer need to restrict to in a fixed congruence class modulo , only to those that avoid collectively the congruence classes mod . We obtain:
Corollary 1.2.
Let and , with . If , then
| (1.6) |
With future applications in mind, we equally treat the case of for an arbitrary finite field with elements for . Indeed, we prove the following twisted version of the isomorphism (1.3):
Theorem 1.3.
Let with and . Let with and . Let be the character of . If , then
Here the are modeled on homogeneous polynomials of degree over in the variables and and means that we twist the standard action of on by the -th power of Frobenius. The polynomials
for are what we call twisted Dickson polynomials (we adopt the convention that ; alternatively, one could index the variables by the group ); they do not seem to appear in the literature.
If , then the periodicity of the quotient on the left hand side again follows since the right hand side only depends on the character which is periodic in modulo . We obtain:
Corollary 1.4.
Let with . Let and with , and . If , then
We end this discussion of the case of principal series by noting that the isomorphism in Theorem 1.3 is expected to play an important role in investigations into the reduction problem of two-dimensional crystalline [Ars21, BL22, BLZ04, Bha20, BG15, BGR18, BGV25, BG09, BG13, GG15, GK24, Gha21, GR23, GV22, Gha24, NP19] and semi-stable representations [BLL23, BM10, Chi24, CG24, CGY25, GP19, LP22] over arbitrary -adic fields with residue field using the compatibility with respect to reduction of the (yet to be discovered) -adic and mod local Langlands correspondences for for an arbitrary finite extension of .
1.2. Cuspidal case
Let be the anisotropic torus. The theme of writing (generalized) principal series representations as cokernels of theta operators raises the question (asked by Khare) as to whether one may similarly write representations induced from the anisotropic torus as cokernels of symmetric power representations.
Let be the differential operator and let be the identity character . We prove the following analog of (1.1):
Theorem 1.5.
One may compare Theorems 1.1 and 1.5 by noting that if we tensor both sides of (1.3) by , then the right hand side of that isomorphism gets replaced by induction from the split torus to of (Remark 1). Theorem 1.5 is also true for (see Remark 3). We prove similar isomorphisms for other values of by twisting (Corollary 4.3) using the fact that preserves the theta filtration in a strong sense (Lemma 4.4). We also prove similar isomorphisms when is replaced by a higher power (Corollary 4.5, note the analogy with (1.3)).
A non-explicit version of the isomorphism in Theorem 1.5 can be deduced from the work of Reduzzi [Red10]. Let us provide some background and explain our contribution. In the discussion that follows, we sometimes think of as a character taking values in a characteristic zero field (by taking its Teichmüller lift). Recall that for each complex character of (with not self-conjugate) there is an irreducible cuspidal complex representation of . Moreover, is a factor of an induced representation: we have
| (1.7) |
where is the -dimensional complex irreducible Steinberg representation of with reduction . While the group has no mod cuspidal representations (since, for instance, the Jacquet functor is never because there are always invariant elements under the upper unipotent subgroup of ), one may still study the mod reductions of . Following a suggestion of Serre to use the operator , Reduzzi [Red10] proved that the mod reduction is isomorphic to the cokernel of on an appropriate symmetric power representation, namely:
| (1.8) |
for . The proof uses a specific integral model of arising from the action of on the crystalline cohomology of the Deligne-Lusztig variety (see Haastert-Jantzen [HJ90]). Thus, Reduzzi’s isomorphism (1.8) is not at all explicit given that the right hand side involves crystalline cohomology. However, by tensoring (1.8) with and using the mod reduction of (1.7) for , one sees that the isomorphism in Theorem 1.5 must hold, at least abstractly. An immediate question that arises is whether one can make this isomorphism explicit, given that the right hand side of this isomorphism no longer involves crystalline cohomology. Thus the point of Theorem 1.5 is that it contains an explicit isomorphism (which was found after much computation with special cases). Again, the map involves a differential operator , where is an element of , which generalizes the operator used in the principal series case.11 1 It also involves the difference of a polynomial evaluated at two points, which looks like the evaluation of a direct integral in calculus.
In fact, Reduzzi [Red10] proved22 2 Technically speaking, Reduzzi does not treat the case , though it is covered by Theorems 1.5 and 1.6. that, more generally, for with , and for the fundamental (identity) character of level , one similarly has
for , where now . We end this paper by proving the following twisted version of this result, which extends Theorem 1.5 to :
Theorem 1.6.
Let where and for all Then there is an explicit isomorphism over :
We remark that where is now the -dimensional Steinberg representation of . Also in the statement of the theorem we need the following twisted versions of Serre’s differential operator , namely:
and
for all . Interestingly, the are only -linear modulo for all (with the convention that is to be thought of as , cf. Lemma 4.6). Again, the do not seem to appear in the literature and one might refer to them as twisted Serre operators.
2. Principal series case
2.1. The case of
Recall and is the subgroup of upper triangular matrices of For let denote the -th symmetric power of the standard representation of over We identify with homogeneous polynomials of degree in two variables and with coefficients in , with action of given by
Consider the Dickson polynomial
Note that acts on by the determinant character. So for each , we have
is a -stable subspace of These spaces give a decreasing filtration of submodules of :
Let denote the character given by . For , , define
Lemma 2.1.
Let . We have
| (2.1) |
Proof.
Follows by induction on . ∎
We introduce the notation: for a polynomial in two variables , and scalars , .
Lemma 2.2.
Let and let with for all Define the differential operators
for . Then, for all we have
Proof.
Lemma 2.3.
Let and Let with and Then for we have
Proof.
This is just the chain rule. ∎
Lemma 2.4.
Let and Let Then, for all , we have
Proof.
This is just Leibniz (Leibnitz in Indian calculus texts!) rule. ∎
Lemma 2.5.
Let We let and Then, for , we have
Proof.
We first show that
| (2.3) |
We prove the result by induction on The case is trivial. Suppose Then, we have
as desired. Assume that the result is true for . If , then
The first equality holds by the induction hypothesis. Note that , so , and hence the last equality follows. Thus the identity (2.3) follows by induction.
Now, suppose Then
| (2.4) |
The second equality follows by taking in (2.3). The last equality follows because
2.1.1. Non-split case
We prove Theorem 1.1 (1) from the introduction.
Theorem 2.6.
Let and . If , then we have
Proof.
First a word on notation. The space (like ) is modelled on homogeneous polynomials over of degree in two variables, say and . However, to prevent confusion with the variables and used to model , we think instead of elements of as tuples with such tuples corresponding to the coefficients of the polynomials in the basis .
Now, define the map
by for all where is defined by
| (2.5) |
for all We show that induces a -equivariant isomorphism between and . Note that, by hypothesis the constant is a well-defined non-zero element of For some motivation on how is constructed for general , it is useful to work out the case , where it is necessary to divide by the constant in the first coordinate.
Recall that we denote and .
-linearity: We first show that is -linear. Let and Then the action of on is given by
We have
which by taking in Lemma 2.2 and by using the fact equals
| (2.6) |
Now,
which, by relabeling as and as , and by further replacing by , equals
| (2.7) |
Observing and comparing (2.6) and (2.7), we have So is -linear and hence is well defined.
-linearity: Now, we show that is -linear. Let , Then where and We have
which, by Lemma 2.3, equals
for all .
So for all
Hence is -linear.
Kernel: Next we show that by induction on . If , it is well known that (e.g., [Roz14, Lemma 2.4] or Lemma 2.11 with ). Let By definition of , we have for all , . In particular, this is true for all So by the induction hypothesis, we have which gives for some Now, taking and using Lemma 2.4,
This implies since, by Lemma 2.5, all terms above die except for the term.
Then by the case, we have , so Thus .
On the other hand if , it is easy to check using Lemmas 2.4, 2.5
that for all .
By the definition of , we have . Thus .
Isomorphism: We have shown induces a -equivariant injection from
to .
This is an isomorphism since both sides have dimension
as .
∎
Remark 1.
To compare Theorem 2.6 and Theorem 1.5 (to be proved in Section 4), we note that the extra factor of in the latter cuspidal setting also occurs in the present principal series setting. To see this, we compare the induction of from the Borel subgroup with that from the split torus of diagonal matrices. We claim that for any representation of , we have
To see this, first observe that . Indeed, since is a group of order prime to , every representation of , in particular the trivial representation , is projective. Since induction of a projective is projective, so is . By Frobenius reciprocity , making the last module the projective envelope of (since the smallest dimension of a projective -module is by, e.g., [Glo78, (2.11)]). Also, is a projective -module and restriction of a projective is projective, so is projective. Since (as the highest monomial), by uniqueness of projective envelopes, we have . Tensoring with yields . Using this, we have
as claimed. Thus tensoring both sides of the isomorphism in Theorem 2.6 with and using the above claim with , we obtain the isomorphism
for , , . This isomorphism is closer in flavor to that in Theorem 1.5.
2.1.2. Split case
We turn to the case . As explained in the introduction we may assume that . In the next theorem, we prove Theorem 1.1 (2). Recall that denotes the two-dimensional split representation of
Theorem 2.7.
Let . If , then we have
Proof.
Define
by where is defined by
| (2.8) |
for , . Note we’ve dropped the factor in the term of (2.5) for .
We check the -linearity of Let and Then,
Here and the fourth equality follows because Hence is -linear.
As discussed in the introduction, we obtain the splitting (1.5):
Corollary 2.8.
Let and . If , that is, for some , then we have
2.2. The case of
Let with for . Let denote the subgroup of upper triangular matrices of Let and let be the -adic expansion of with and Let for all where denotes the Frobenius morphism. Let be modeled on polynomials in and over of degree for all Let
| (2.9) |
for all denote the twisted Dickson polynomials.
Lemma 2.9.
Let We write
Let with for all Then, for all we have
Proof.
Similar to Lemma 2.2. ∎
Lemma 2.10.
Let and Let where and Then for we have
Proof.
Similar to Lemma 2.3. ∎
Lemma 2.11.
Let Let be such that for all Then
Proof.
Exercise. ∎
Lemma 2.12.
Let We let and Then we have
Proof.
Similar to Lemma 2.5. ∎
Lemma 2.13.
For , and , let
be defined by where is given by
for all and Then
-
is -linear,
-
is -linear,
-
induces an isomorphism from to .
Proof.
-linearity: Let and Let Then the action of on is given by
As in the proof of Theorem 2.6, but using Lemma 2.9 instead, . Thus is -linear.
Isomorphism: We now show by induction on that where Suppose Then is defined by . Clearly Let Then for all Thus, for all Then by Lemma 2.11, we have So Thus
Assume that the result is true for By Lemma 2.12, we have
for all By definition of we have So Let Then for all In particular, for all By the induction hypothesis Write with Now, taking and proceeding exactly as in the proof of Theorem 2.6, but using Lemma 2.12 instead, we see divides So Thus
So induces an injective map . Note that the dimension of both sides is as . So this map is also surjective and an isomorphism. ∎
Remark 2.
It is also possible to give a direct proof of the surjectivity of , at least when . Let be a representation of For , let denote the map defined by
A basis of is given by (cf. [Bre07, Lemma 7.2], [BP12, Lemma 2.5 (2)] )
| (2.10) |
where denotes the function supported on and for all When, e.g., and , then one may check maps to for , and maps to .
Similarly for , arbitrary, a basis of is given by
where is modeled on polynomials of degree over in , and , are in as in (2.10). One should similarly be able to write down polynomials mapping to these basis elements under .
Theorem 1.3 is a twisted version of the Lemma 2.13. However the proof is more involved. To prove it we need a few more lemmas. Recall the twisted Dickson polynomials for were defined in (2.9).
Lemma 2.14.
Let For and let Then
Proof.
For assume that . Then Note that does not determine the and the are not the digits of the base expansion of . Let for . Set and We write
Lemma 2.15.
For , let and . Let . Let be such that for all . Then and the polynomial is of the form
Proof.
From the given condition we have , . In particular, choosing we have and choosing we have Let Then taking we have
which, by writing , gives Since the (essentially) Vandermonde matrix is invertible, we have
| (2.11) |
for all (see also [Bre03, Lemme 3.1.6], [Hen19, Lemma 2.8]). Now, we have
The last equality follows from (2.11). ∎
Lemma 2.16.
Let and for all For let be such that with Let
where for some Assume that has no pure term which involves either only or only Then, for there exist , such that
with
Proof.
We first make two observations. First, if then we may write
which implies that
| (2.12) |
Second, for if then similarly
| (2.13) |
Note that the first operation involving decreases in (2.12) by . However, the second operation involving does not change in (2.13).
Now, to prove the result we may assume that (replacing by -). We also assume that . If , we iterate the argument below to reduce to the case .
Case 1: Suppose
First assume . Since and by (2.12), we have
Note that,
Thus the result follows by taking and for all
Next suppose Since there is no pure term in in we choose to be the least index for which in Then we have for all and This implies that for all and Then, using (2.13), we have
Clearly and we are reduced to the previous paragraph ().
Case 2: Suppose
Suppose, We write with Since by assumption and we have This shows that Now, if taking by (2.13) we have
Note that So we are done by the ‘’ case above. And so on.
Thus it is enough to show that this process stops. Suppose not. Then for we have such that In particular, Now, note that
Since we have Also, note that by assumption. Hence,
for all This is a contradiction because does not contain any pure term in Thus modulo we can always assume that hence by Case the result follows. ∎
Lemma 2.17.
Let for all For let be such that with Let
where Then
Proof.
We make the following observation. For if then
| (2.14) |
Note that the operation involving in (2.14) does not change the sum
Now, we prove the result by induction on If then and hence, the result follows. Assume that the result is true for Without loss of generality we assume that If we are done by the induction hypothesis.
Suppose We assume that If this difference is bigger than , then we iterate the proof below until it is . Clearly If taking in (2.14), we have
Since the operation involving does not change the sum and we are done by the case ‘’.
If we write where and Since by assumption we have Now, if taking in (2.14), we have
Since the operation involving does not change the sum and we are done by the ‘’ case. And so on.
Thus it is enough to show that this process stops. Suppose not. Then for we have such that In particular, By hypothesis, we have
which by substituting and for all gives
which further by substituting implies that
Since we conclude But we had Thus we arrive at a contradiction. So modulo we are always reduced to the ‘’ case, and so we are done. ∎
We finally prove Theorem 1.3 from the introduction.
Theorem 2.18.
Let be the -adic expansion of with . Let with for all . If for all then we have
Proof.
Define
by , where for all , and
is given by
We show that induces a -equivariant isomorphism between the right and left hand sides of the isomorphism in the statement of the theorem.
We first show that is -linear. This follows from the -linearity of each . Let and Then
The second equality holds by Lemma 2.13 (i).
Similarly, for the -linearity of we note that , which by Lemma 2.13 (ii), equals
Now there is a natural surjection
given by with for all . Note that is not necessarily injective (take and compare dimensions on both sides of ). By definition of , we have that for all . Hence we have that . But the last map is equal to . Thus
By Lemma 2.13 (iii), each is surjective, hence so is . Since is surjective, so is .
Note that each is not injective, hence is not injective, therefore is not injective. Thus it remains to compute . We show that where we write instead of for emphasis. By Lemma 2.14, for
for all By the definition of we see that . We now prove the other containment
| (2.15) |
This is the trickiest part of the proof of the theorem. We will use the three lemmas proved before the theorem.
The proof is by induction on where denotes the sum of the -adic digits in the base expansion of If then we have for all Noting that for , we see that (2.15) follows immediately from Lemmas 2.15, 2.16 and 2.17.
Now, suppose . Assume that (2.15) holds for with . Pick such that Let Then and so
| (2.16) |
by the induction hypothesis. Now, let So for all In particular, for all with and for all This shows that By (2.16), we may write
with for Clearly,
So without loss of generality, let Since for and we have
The fourth implication follows from Lemma 2.14: if , then
and is for all other . The penultimate implication holds by the induction hypothesis as the sum of the -adic digits is . So proving (2.15). ∎
3. Dual numbers
This section is an aside. The ring of generalized dual numbers is defined by We make some remarks on two questions that arise in the context of the lack of surjectivity when of the map (1.2) which involves dual numbers (introduced in [GV22, Lemma 4.1]). Firstly, can one possibly replace the inducing subgroup in (1.2) by another subgroup of index in and by a surjective character such that there is an isomorphism
which might then be used to study periodicity results? The answer is no, and explains why in this paper we turned towards proving the isomorphism in Theorem 1.1. Secondly, can one at least describe the image of (1.2) in a more conceptual way than in [GV22, Lemma 4.1]? The answer in some cases is yes (see Proposition 3.1 and a longer arXiv version of this paper https://arxiv.org/pdf/2308.10246 for its proof).
It would be interesting to see how the material in this section connected to announced work of Schein and his coauthors on the modular representation theory of where is a finite quotient ring of for a -adic field, and, e.g., to work of Avni, Onn, Prasad, Vaserstein [AOPV].
3.1. Isomorphisms using dual numbers
There are two notions of projective space over the generalized dual numbers. The first is standard projective space
It has cardinality when and is the cylinder obtained by glueing the line at , namely , to the plane [Gru06]. The second is . It has cardinality when . The group acts on the left on both these spaces via .
Let be the -Iwahori subgroup of obtained as the pre-image of the usual Borel under the reduction modulo map . Then is the stabilizer of under the action of on (whereas is the stabilizer of in ). Clearly has index .
One may ask if there is a surjective character which induces a -isomorphism
from which the periodicity of the left side would follow if one knew only depended on modulo .
The answer is no. Indeed, one quickly sees that has abelianization and so the only surjective characters it supports are powers of the determinant character. These characters are not genuine characters of , since they are obtained by restricting from , so the induction is not so well-behaved.
Moreover, one checks that every other subgroup of index in is conjugate to so this line of reasoning does not bear fruit.
3.2. Image of (1.2)
Thus, the best one can hope to do is to characterize the image of the (non-surjective) map (if )
mentioned in the introduction (cf. [GV22, Lemma 4.1]).
To this end, we consider the right action of on standard projective space defined via . This action is transitive and the stabilizer of under this action is We have the following decomposition
where There is a bijection between and by sending to for .
We say that is smooth if for all with and with and all , there exist constants and in such that
Proposition 3.1.
Let be given by for all where is defined by for If mod , then
4. Cuspidal case
In this section, we prove Theorems 1.5 and 1.6 which, as explained in the introduction, are the cuspidal analogs of Theorems 1.1 and 1.3.
4.1. The case of
Let be such that and Fix an identification given by for , not both zero. Recall that is the inverse of .
We define some functions in induced spaces. For and let be
for all Then is -linear and hence Indeed, for we have
which equals
One can check that the functions in are linearly independent. Also, has index in So forms a basis of We fix this basis in the computations to follow.
For we observe that
| (4.1) |
for some In this case, we say that is a flip. We shall soon assume that in which case lies in .
On the other hand, for we have for some Then we say that is a flop. It is the last term in the following relation:
| (4.2) |
where all but the last term lie in . Indeed, we have
Then for we have . So for we have
which, after multiplying by on both sides, gives
which shows that (4.2) holds for .
Thus, any flip or flop can be expressed as an easy linear combination of vectors in using (4.1), (4.2).
For any polynomial and , we set
The following theorem is Theorem 1.5 from the introduction (replacing by ).
Theorem 4.1.
Let Then there is an explicit isomorphism defined over :
where .
Proof.
Let and Define
| (4.3) |
by where is defined by
for all and where
For convenience, we set
| and | (4.4) |
We think of and as -valued functions on . We remark that the
definition (4.3) of reminds one of the evaluation of a direct integral in calculus. It was
arrived at after much explicit computation with special cases.
-linearity: We show that is -linear. Since is a homogeneous polynomial of degree and is a homogeneous polynomial of degree we have is a linear combination of terms of the form
for and Now,
which shows that is a linear combination of the functions defined above.
Since these functions are -linear,
is also -linear.
-linearity: We show that is -linear. Let Then we have
where and Now,
which, by Lemma 2.10 applied twice
Thus we have Hence is -linear.
Kernel of : Next we show that We first show that . Let and Then . Claim: for all we have .
Indeed,
which, by observing equals if and equals if ,
which again using for for and for and for
Since modulo and modulo the above expression
Note that since we have
Also,
Thus we have,
proving the claim, and so Thus
Next, we show that . We prove this inclusion by changing to i.e., we show
for where
such that ,where is defined by
| (4.5) |
for all We use the latter notation since we reduce the rest of the proof of Theorem 4.1 to some determinant computations in a longer arXiv version of this paper https://arxiv.org/pdf/2308.10246 where is replaced by .
Let
| (4.6) |
where is modeled on polynomials in ,. Then we have
| (4.7) |
Now,
| (4.8) |
In the last equality, we dropped the terms for as these are zero. Indeed, for since for only the term survives in the sum over for which
Similarly, one can check that the terms for are also zero. The expression (4.1)
| (4.9) |
since is independent of and, by (2.1),
Consider now the expression (4.9) as a polynomial in the variables .
We compute the coefficients of and in this polynomial for .
Coefficient of : Note that for and we have for and for Thus the coefficient of in (4.9)
Coefficient of : Similarly, in (4.9), the coefficient of is
The first equality holds because for and for .
The second equality follows because
.
For substituting the coefficients of and in (4.9), we have
Thus (4.7) shows that the following linear combination of functions in the induced space vanishes:
| (4.10) | ||||
after dividing by .
For simplicity, we make the change of variables
for and and,
for , , The are variables (and the constants).
We claim that all the must be . The proof of this is computational. It will occupy the next few pages.
To reduce the length of the proof we have referred to some determinant computations which are in the
longer arXiv version of this paper https://arxiv.org/pdf/2308.10246. The first time reader may skip to the end of the proof of
Theorem 4.1.
Claim: For and we have .
We prove the claim. Write (4.10) as
Collecting terms in the same congruence class of modulo , we have
Write the -th summand above as for . Recall that we are viewing and as functions on , cf. (4.4). By inspection, each of the functions in is of the form for modulo . Note that is an element of . Using (4.1) and (4.2), we may assume each of these functions belong to the basis , noting that these operations preserve the congruence class . By the linear independence of the basis and the vanishing of the sum of the , we conclude that each . Thus fixing we have:
| (4.11) |
The possible pairs of such that for and are:
| (4.12) |
We analyze three cases:
Looking at the indices occurring in in the above equation, we note for each , there is a unique But for we get both and For convenience, we drop the index for : we write
| (4.14) |
Now, there is no flip or flop in the first summand of the above equation. If then there is one flip in the first component of the second summand and one flop in its second component. Also, for , there is one flop in the first component of the second summand if (and the term is not there if ). Finally in the third summand, there are flips for and there is one flop for . Apart from these there are no flips and flops appearing in the above equation.
Assume that . Changing the flips and flops appearing in (4.1) to functions in and looking at the coefficient of for we get the following system of equations:
| (4.15) |
Case 2: Suppose In this case, by (4.1) we have
In the second but last sum above there are flips for all Also, there is a flop in the last sum at As before, by changing the flips and flops appearing in the above equation to functions in and then looking at the coefficient of for and using the convention (4.14) for the variables, we get the following system of equations:
| (4.16) | |||||
Case 3: Suppose From (4.1) we have,
| (4.17) |
There are flops in the first component of the first sum for and in the second sum for . Also, there are flips in the second last line above for all and in the last line. Changing the flips and flops appearing in the above equation to functions in , looking at the coefficient of for and using the convention (4.14) for the variables, we have the following system of equations:
| (4.18) | |||||
Let be the coefficient matrix of the above systems of equations in Cases 1, 2 and 3, respectively.
A computation shows that . In fact, one can give
a formula for in each case
but we do not need it, so to keep this paper a reasonable size, we omit it
(details about this and other omitted arguments in this current abridged version of the paper may be
found in an earlier version
of the paper on the arXiv at https://arxiv.org/pdf/2308.10246.pdf).
It follows that in each case for .
Thus we have for all and , proving the Claim.
Using these relations, we have
Each term in the last equality belongs to and hence, so does Thus and so equality holds. Changing back to we have .
Thus induces an injective map . Since both sides have the same dimension , we conclude that the induced map is an isomorphism. This finally proves Theorem 4.1. ∎
We have proved Theorem 1.5 for One might wonder what happens for boundary values of . Theorem 1.5 is also true if , though the definition of the map needs to be changed a bit.
Proposition 4.2.
We have
Proof.
Remark 3.
In fact, Proposition 4.2 is true ‘without tensoring with ’. That is, Reduzzi’s result (1.8) even holds for . Indeed, one has
by Diamond [Dia07, Proposition 1.3] (this does not use crystalline cohomology, see also the material around Prasad [Pra10, Lemma 4.2] for a survey: in fact, the reduction mod of the complex cuspidal representation for of is irreducible if and only if ). On the other hand, if , then Theorem 1.5 is false for dimension reasons. Since , the right hand side of the isomorphism in the theorem reduces to the case . As for the left side, one easily checks
is a principal series representation. Similarly, if then is self-conjugate and the induction on the right side is not as interesting, whereas on the left side one checks
is a twist of the mod Steinberg representation.
In view of Proposition 4.2 and Remark 3, we see Theorem 4.1 holds for but not for , . However, by twisting, the theorem may be extended to the following higher symmetric powers:
Corollary 4.3.
If for then
Proof.
We first show that
for . Define by sending to for Let Then where the last equality follows because Thus we have and hence,
is a surjection. Also, both sides have dimension so is an isomorphism.
For the second isomorphism, consider the composition
| (4.19) |
In the above, the first map is the natural inclusion map and the second one is the natural surjection map. Note that, the kernel of the map (4.19) is We show that
Clearly, The other containment is trivially true for . To establish it for , we need the following lemma which is easily proved by checking the two conditions in [GV22, Lemma 2.7].
Lemma 4.4.
If and , then
Remark 4.
By the lemma, induces an inclusion
which is an isomorphism for dimension reasons. This provides another proof of (1.6) using the map, under the slightly stronger assumptions and . The last condition is necessary (for instance, for , if , then maps , to , so the map above is not injective).
Now, let for some , and . By Lemma 4.4, we have if and only if . Thus and hence . So the kernel of (4.19) is Thus, there is an injection
If and then is injective on Otherwise, by [Red10, Proposition 3.3] and comparing degrees, we would have a relation of the form for some . Comparing -adic digits on both sides and noting they are in the range , we have and . The first equality implies , whereas the second implies , a contradiction. Thus the dimension of each side of the inclusion above is So it is an isomorphism.
Corollary 4.5.
Let and Then, we have
4.2. The case of
We now prove Theorem 1.6, which is a twisted version of Theorem 4.1. Recall that and is a basis of , for all
Lemma 4.6.
Let . We define
and
for all Then, the maps
- (1)
- (2)
are -linear.
Proof.
. We show that is -linear modulo By Bruhat decomposition, it is enough to check that modulo for either diagonal, the Weyl element or upper unipotent. The case when diagonal is clear. If , then
Finally, if for , then
| (4.20) | |||||
and
| (4.21) | |||||
so taking the difference of (4.20) and (4.21), we have
| (4.22) |
The term in the parentheses
where means is omitted from the sum and means is omitted from the sum. Writing and the above expression
where the fourth sum above is obtained by the transformation in the second sum above, which, together with (4.2), gives
Thus is -linear modulo
(2). The proof is similar and is omitted. ∎
Let be such that , Fix an identification given by .
Let and Let be a function such that
for all Then and the set forms a basis of Indeed, let and Then we have
which equals . One can check that the functions in are linearly independent. Also, has index in So forms a basis of
For we observe that
| (4.23) |
for some We say that is a flip. We soon assume that , so .
On the other hand, for we have for some We say that is a flop since it satisfies the following relation:
| (4.24) |
where all terms but the last are in . Indeed, since , for we have . Thus for
which, after multiplying by , gives
which shows (4.24).
Thus, by using (4.23) and (4.24), any flip or flop can be changed to an easy linear combination of functions in We fix the basis in the computations to follow.
For any we denote and For any polynomial and , we write
Lemma 4.7.
Let with and for all Let with a homogeneous polynomial of degree in , and homogeneous of degree in , Define by
where
for all Then the map
- (1)
is -linear.
- (2)
such that is -linear.
Proof.
-linearity: Note is a linear combination of terms
where and Now,
where in the last but one equality Thus is a linear combination of functions of the form above
and hence is -linear.
-linearity: Let Note that,
where . Now,
| (4.25) |
Applying Lemma 2.10 (twice), for and we have
where and Observe that, in the last equality in writing the top limits in terms of and we use the fact that and are in
Now taking, for and for the expression in (4.2) equals
The following lemmas will be useful in the proof of the main theorem.
Lemma 4.8.
Let
Then,
- (1)
we have if and only if
for and
for and all for .
- (2)
for we have if and only if
where and and in the remaining cases
Proof.
The conditions are clearly necessary, and can be checked to be sufficient. ∎
Lemma 4.9.
Let and let
Then we have if and only if the following hold:
- (1)
for we have
- (2)
for and all for we have
- (3)
for and for all and we have
Proof.
Say We show conditions , , are satisfied. Write where
for all Then
with each satisfying the conditions of Lemma 4.8. Now (2) is clear since if , each term on the right vanishes by (both parts of) Lemma 4.8. Condition (1) is also clear, since if and the other are all or all , then all the terms on the right vanish for , by the second part of Lemma 4.8, and the term on the right satisfies the desired identity by the first part. Similarly (3) holds, since if and the other are not all or not all , then the term on the right vanishes by the first part of the lemma and the remaining terms satisfy the desired identity by the second part, whence so does their sum.
For the converse, note that can be written as
which, by the transformations and in the fourth sum above (and dropping the summations for in the first and fourth sum) and by the transformation in the last sum, can be rewritten as
| (4.26) |
Now suppose the conditions , , hold. Then by (4.2), we can write the polynomial as
This implies that ∎
Remark 5.
In Lemma 4.9, there are no conditions on the coefficients and of . So if , then the dimension of over is
The following theorem is Theorem 1.6 from the introduction.
Theorem 4.10.
Let where and for all Recall that
and
for all Then over we have
Proof.
Define as in Lemma 4.7. Recall that for we have where now noting that for , we have is defined by
where . By Lemma 4.7 (1), the map is -linear and hence is well defined. It is also -linear by Lemma 4.7 (2).
We show that . The proof occupies the rest of this paper.
First we show
Case 1: Suppose We show that For we have
We claim
| (4.27) |
Indeed, we have
| (4.28) | |||||
and similarly
| (4.29) | |||||
Ignoring the factor and using (4.28), the first summand on the left side of (4.2) becomes
which, by noting
and, dividing by ,
equals
| (4.30) |
Again, ignoring the common factor and using (4.29), a similar computation shows that the second summand on the left hand side of (4.2) is
| (4.31) |
which is the negative of (4.2). This proves the claim (4.2).
Hence Im for all
Case 2: The proof that is similar and is omitted.
Combining Cases and we see that
.
Next we show that Let
where and , . By definition of , for all , we have
| (4.32) |
Note, for each ,
| (4.33) |
Now by fixing and only considering the sum over in (4.2), we have
which by observing , and writing
| (4.34) |
equals
| (4.35) |
The last equality holds since by (2.1), we have
Moreover, we have adorned the limits in the last two sums with ′s to indicate that we drop the terms corresponding to and . Indeed, if then and
So the term for in (4.2) is
Similarly, one may check that the term for is zero.
For notational convenience, set
Then (4.2) decomposes as
| (4.36) |
By taking , the coefficient of in the first sum above is
Note that, by (4.34), for we have
Thus the coefficient of becomes
which further equals
| (4.37) |
Now use the transformation in the second sum of (4.2). By taking , the coefficient of is given by
For we have
Thus the coefficient of becomes
which equals
| (4.38) |
Finally, using and in the fifth sum of (4.2), and noting that changes to
the coefficient of equals
| (4.39) |
which is exactly the coefficient of obtained by taking in , since for Summarizing, the transformation in the second sum of (4.2) and the transformations and in the fifth sum of (4.2), together with (4.37), (4.38) and (4.39), allow us to rewrite (4.2) as
| (4.40) |
Now, for each , let and , and set
Note that and , so there are variables , with the first kind running in the range , and the second and third kind running in the range .
By (4.2), and (4.33), and (4.2) but with the variables , we obtain
which by dividing by and setting (cf. (4.34))
yields the system of equations (that was obtained earlier in (4.10) for )
As before, we separate the equations according to the congruence class of the sum so that we obtain separate systems of equations (each with distinct variables). Again in order to work in the basis , we convert all flips and flops to elements of using (4.23) and (4.24). The resulting equations and corresponding coefficient matrices obtained and the computation using row operations to show that these matrices have non-zero determinant are identical to the case of treated earlier. The only real difference is that in the formulas for the determinant (obtained earlier in three cases depending on the relative size of ), one needs to replace by everywhere. We conclude that all . That is, for each , we have
- (1)
if and for , then
- (2)
if and for then
- (3)
if and there is a (smallest) with (so for and then
Then,
where each polynomial in the parentheses satisfies , , . So by Lemma 4.9, we conclude , showing We finally have
By Remark 5, the dimension of over equals so after tensoring with ,
Thus, over we have , and so must be an isomorphism. This completes the proof of Theorem 4.10 (which is also Theorem 1.6). ∎
Acknowledgements: We thank A. Chitrao, C. Khare and S. Varma for useful discussions. Both authors thank the referee for many useful comments and suggestions. The first author thanks ANU, Canberra for its hospitality during March 2024.
References
- [Alp86] Jonathan L. Alperin, Local representation theory. Cambridge Studies in Advanced Mathematics, 11, Cambridge University Press (1986).
- [Ars21] Bodan Arsovski, On the reductions of certain two-dimensional crystalline representations, Doc. Math. 26 (2021), 1929–1979.
- [AOPV] Nir Avni, Uri Onn, Amritanshu Prasad and Leonid Vaserstein, Similarity classes of matrices over a local principal ideal ring, Comm. Algebra 37 (2009), no. 8, 2601–2615.
- [BL22] John Bergdall and Brandon Levin, Reductions of some two-dimensional crystalline representations via Kisin modules, Int. Math. Res. Not. IMRN (2022), no. 4, 3170–3197.
- [BLL23] John Bergdall, Brandon Levin and Tong Liu, Reductions of 2-dimensional semistable representations with large -invariant, J. Inst. Math. Jussieu 22 (2023), no. 6, 2619–2644.
- [BLZ04] Laurent Berger, Hanfeng Li and Hui June Zhu, Construction of some families of 2-dimensional crystalline representations, Math. Ann. 329 (2004), no. 2, 365–377.
- [Bha20] Shalini Bhattacharya, Reduction of certain crystalline representations and local constancy in the weight space, J. Théor. Nombres Bordeaux 32 (2020), no.1, 25–47.
- [BG15] Shalini Bhattacharya and Eknath Ghate, Reductions of Galois representations for slopes in , Doc. Math. 20 (2015), 943–987.
- [BGR18] Shalini Bhattacharya, Eknath Ghate and Sandra Rozensztajn, Reductions of Galois representations of slope 1, J. Algebra 508 (2018), 98–156.
- [BGV25] Shalini Bhattacharya, Eknath Ghate and Ravitheja Vangala, Reductions of crystalline representations of slope less than , in preparation.
- [Bre03] Christophe Breuil , Sur quelques représentations modulaires et -adiques de . I, Compositio Math. 138 (2003), no. 2, 165–188.
- [Bre07] Christophe Breuil, Representations of Galois and of in characteristic , Graduate course at Columbia University (fall 2007), https://www.imo.universite-paris-saclay.fr/˜christophe.breuil/PUBLICATIONS/New-York.pdf, 1–90.
- [BM10] Christophe Breuil and Ariane Mézard, Représentations semi-stables de , demi-plan -adique et réduction modulo , Astérisque (2010), no. 331, 117–178.
- [BP12] Christophe Breuil and Vytautas Paškūnas, Towards a modulo Langlands correspondence for , Memoirs of the American Mathematical Society, 216 (2012), no. 1016, vi+114.
- [BG09] Kevin Buzzard and Toby Gee, Explicit reduction modulo of certain two-dimensional crystalline representations, Int. Math. Res. Not. IMRN (2009), no. 12, 2303–2317.
- [BG13] Kevin Buzzard and Toby Gee, Explicit reduction modulo of certain 2-dimensional crystalline representations, II, Bull. Lond. Math. Soc. 45 (2013), no. 4, 779–788.
- [Chi24] Anand Chitrao, An Iwahori theoretic mod Local Langlands Correspondence, Canad. Math. Bull. (2025), to appear.
- [CG24] Anand Chitrao and Eknath Ghate, Reductions of semi-stable representations using the Iwahori mod Local Langlands Correspondence, preprint, https://arxiv.org/abs/2311.03740 (2024), 105 pp.
- [CGY25] Anand Chitrao, Eknath Ghate and Seidai Yasuda, Semi-stable representations as limits of crystalline representations, Algebra Number Theory (2025), to appear.
- [Dia07] Fred Diamond, A correspondence between representations of local Galois groups and Lie-type groups, London Math. Soc. Lecture Note Ser., Cambridge Univ. Press, Cambridge, 320 (2007), no. 187–206.
- [GG15] Abhik Ganguli and Eknath Ghate, Reductions of Galois representations via the local Langlands correspondence, J. Number Theory 147 (2015), 250–286.
- [GK24] Abhik Ganguli and Suneel Kumar, On the local constancy of certain Galois representations, Res. Number Theory 10 (2024), no. 2, Paper No. 52, 43 pp.
- [Gha21] Eknath Ghate, A zig-zag conjecture and local constancy for Galois representations, RIMS Kôkyûroku Bessatsu B86 (2021), 249–268.
- [Gha24] Eknath Ghate, Zig-zag for Galois representations, preprint, https://arxiv.org/abs/2211.12114 (2024), 10 pp.
- [GR23] Eknath Ghate and Vivek Rai, Reductions of Galois representations of slope , Kyoto J. Math. (2025), to appear.
- [GV22] Eknath Ghate and Ravitheja Vangala, The monomial lattice in modular symmetric power representations.. Algebr. Represent. Theory 25 (2022), no. 1, 121–185.
- [Glo78] D. J. Glover, A study of certain modular representations, J. Algebra 51 (1978), no. 2, 425–475.
- [Gru06] Josef Grünwald, Über duale Zahlen und ihre Anwendung in der Geometrie, Monatshefte für Mathematik 17 (1906), 81–136.
- [GP19] Lucio Guerberoff and Chol Park, Semistable deformation rings in even Hodge-Tate weights, Pacific J. Math. 298 (2019), no. 2, 299–374.
- [HJ90] Burkhard Haastert and Jens C. Jantzen, Filtrations of the discrete series of via crystalline cohomology, J. Algebra 132 (1990), no. 1, 77–103.
- [Hen19] Yotam I. Hendel, On the universal supersingular quotients for over for a general , J. Algebra 519 (2019), 1–38.
- [LP22] Wan Lee and Chol Park, Semi-stable deformation rings in even Hodge-Tate weights: the residually reducible case, Int. J. Number Theory 18 (2022), no. 10, 2171–2209.
- [NP19] Enno Nagel and Aftab Pande, Reductions of modular Galois representations of Slope , preprint, https://arxiv.org/abs/1801.08820 (2019).
- [Pra10] Dipendra Prasad, Notes on modular representations of -adic groups, and the Langlands correspondence, preprint, https://arxiv.org/abs/1404.6631 (2010), 14 pp.
- [Red10] Davide A. Reduzzi, Reduction mod of cuspidal representations of and symmetric powers, J. Algebra 324 (2010), no. 12, 3507–3531.
- [Roz14] Sandra Rozensztajn, Asymptotic values of modular multiplicities for , J. Théor. Nombres Bordeaux 26 (2014), no. 2, 465–482.